from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

MCU_Microchip_AVR = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'AT90CAN32-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN32-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN32-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90CAN32-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN32-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN32-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90PWM1-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90PWM1-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_7x7mm_P0.65mm_EP4.65x4.65mm', 'keywords':'AVR 8bit Microcontroller LightingAVR PWM', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc4378.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90PWM1-16M\n\nAVR 8bit Microcontroller LightingAVR PWM', 'pins':[
            Pin(num='1',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL1/PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='XTAL2/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='18',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='19',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='21',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='22',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='23',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='26',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='30',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='31',name='~{RESET}/PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90PWM1-16S', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90PWM1-16S'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm'], 'footprint':'Package_SO:SOIC-24W_7.5x15.4mm_P1.27mm', 'keywords':'AVR 8bit Microcontroller LightingAVR PWM', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc4378.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90PWM1-16S\n\nAVR 8bit Microcontroller LightingAVR PWM', 'pins':[
            Pin(num='1',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='XTAL1/PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='XTAL2/PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='18',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='~{RESET}/PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PB1',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB162-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB162-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-32_7x7mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-32_7x7mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7707.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB162-16A\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB646-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB646-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB646-A\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB646-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB646-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB646-M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB82-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB82-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7707.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB82-16M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90CAN128-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN128-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN128-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90CAN128-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN128-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN128-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90CAN64-16A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN64-16A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN64-16A\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90CAN64-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90CAN64-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller MegaAVR', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7679.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90CAN64-16M\n\nAVR 8bit Microcontroller MegaAVR', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PG3',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PG4',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PG0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PG1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='PE2',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PG2',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='PE3',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='AGND',func=pin_types.PWRIN,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PE7',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB1286-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB1286-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB1286-A\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB1286-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB1286-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB1286-M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB1287-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB1287-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB1287-A\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB1287-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB1287-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB1287-M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB162-16M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB162-16M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm', 'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm'], 'footprint':'Package_DFN_QFN:QFN-32-1EP_5x5mm_P0.5mm_EP3.6x3.6mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7707.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB162-16M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='~{HWB}/PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PC0/XTAL2',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='21',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='22',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='23',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='24',name='PC1/~{RESET}',func=pin_types.BIDIR,unit=1),
            Pin(num='25',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='28',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='29',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='32',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='33',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='7',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='8',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='9',name='PD3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB647-A', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB647-A'}), 'ref_prefix':'U', 'fplist':['Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'Package_QFP:TQFP-64_14x14mm_P0.8mm'], 'footprint':'Package_QFP:TQFP-64_14x14mm_P0.8mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB647-A\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'AT90USB647-M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'AT90USB647-M'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm'], 'footprint':'Package_DFN_QFN:QFN-64-1EP_9x9mm_P0.5mm_EP7.5x7.5mm', 'keywords':'AVR 8bit Microcontroller USB', 'description':'', 'datasheet':'http://ww1.microchip.com/downloads/en/DeviceDoc/doc7593.pdf', 'search_text':'/usr/share/kicad/symbols/MCU_Microchip_AVR.kicad_sym\nAT90USB647-M\n\nAVR 8bit Microcontroller USB', 'pins':[
            Pin(num='1',name='PE6',func=pin_types.BIDIR,unit=1),
            Pin(num='10',name='PB0',func=pin_types.BIDIR,unit=1),
            Pin(num='11',name='PB1',func=pin_types.BIDIR,unit=1),
            Pin(num='12',name='PB2',func=pin_types.BIDIR,unit=1),
            Pin(num='13',name='PB3',func=pin_types.BIDIR,unit=1),
            Pin(num='14',name='PB4',func=pin_types.BIDIR,unit=1),
            Pin(num='15',name='PB5',func=pin_types.BIDIR,unit=1),
            Pin(num='16',name='PB6',func=pin_types.BIDIR,unit=1),
            Pin(num='17',name='PB7',func=pin_types.BIDIR,unit=1),
            Pin(num='18',name='PE4',func=pin_types.BIDIR,unit=1),
            Pin(num='19',name='PE5',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='PE7',func=pin_types.BIDIR,unit=1),
            Pin(num='20',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='21',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='22',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='23',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='PD0',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='PD1',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='PD2',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='PD3',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='PD4',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='UVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='PD5',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='PD6',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='PD7',func=pin_types.BIDIR,unit=1),
            Pin(num='33',name='PE0',func=pin_types.BIDIR,unit=1),
            Pin(num='34',name='PE1',func=pin_types.BIDIR,unit=1),
            Pin(num='35',name='PC0',func=pin_types.BIDIR,unit=1),
            Pin(num='36',name='PC1',func=pin_types.BIDIR,unit=1),
            Pin(num='37',name='PC2',func=pin_types.BIDIR,unit=1),
            Pin(num='38',name='PC3',func=pin_types.BIDIR,unit=1),
            Pin(num='39',name='PC4',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='D-',func=pin_types.BIDIR,unit=1),
            Pin(num='40',name='PC5',func=pin_types.BIDIR,unit=1),
            Pin(num='41',name='PC6',func=pin_types.BIDIR,unit=1),
            Pin(num='42',name='PC7',func=pin_types.BIDIR,unit=1),
            Pin(num='43',name='PE2/~{HWB}',func=pin_types.BIDIR,unit=1),
            Pin(num='44',name='PA7',func=pin_types.BIDIR,unit=1),
            Pin(num='45',name='PA6',func=pin_types.BIDIR,unit=1),
            Pin(num='46',name='PA5',func=pin_types.BIDIR,unit=1),
            Pin(num='47',name='PA4',func=pin_types.BIDIR,unit=1),
            Pin(num='48',name='PA3',func=pin_types.BIDIR,unit=1),
            Pin(num='49',name='PA2',func=pin_types.BIDIR,unit=1),
            Pin(num='5',name='D+',func=pin_types.BIDIR,unit=1),
            Pin(num='50',name='PA1',func=pin_types.BIDIR,unit=1),
            Pin(num='51',name='PA0',func=pin_types.BIDIR,unit=1),
            Pin(num='52',name='VCC',func=pin_types.PASSIVE,unit=1),
            Pin(num='53',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='54',name='PF7',func=pin_types.BIDIR,unit=1),
            Pin(num='55',name='PF6',func=pin_types.BIDIR,unit=1),
            Pin(num='56',name='PF5',func=pin_types.BIDIR,unit=1),
            Pin(num='57',name='PF4',func=pin_types.BIDIR,unit=1),
            Pin(num='58',name='PF3',func=pin_types.BIDIR,unit=1),
            Pin(num='59',name='PF2',func=pin_types.BIDIR,unit=1),
            Pin(num='6',name='UGND',func=pin_types.PWRIN,unit=1),
            Pin(num='60',name='PF1',func=pin_types.BIDIR,unit=1),
            Pin(num='61',name='PF0',func=pin_types.BIDIR,unit=1),
            Pin(num='62',name='AREF',func=pin_types.PASSIVE,unit=1),
            Pin(num='63',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='64',name='AVCC',func=pin_types.PWRIN,unit=1),
            Pin(num='65',name='GND',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='UCAP',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VBUS',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='PE3',func=pin_types.BIDIR,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Sensor_Humidity = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'ENS210', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'ENS210'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:AMS_QFN-4-1EP_2x2mm_P0.95mm_EP0.7x1.6mm'], 'footprint':'Package_DFN_QFN:AMS_QFN-4-1EP_2x2mm_P0.95mm_EP0.7x1.6mm', 'keywords':'relative humidity temperature i2c pre-calibrated', 'description':'', 'datasheet':'http://ams.com/eng/Products/Environmental-Sensors/Relative-Humidity-and-Temperature-Sensors/ENS210', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nENS210\n\nrelative humidity temperature i2c pre-calibrated', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='GND',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HDC1080', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HDC1080'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_PWSON-N6'], 'footprint':'Package_SON:Texas_PWSON-N6', 'keywords':'Temperature Humidity Sensor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/hdc1080.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nHDC1080\n\nTemperature Humidity Sensor', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='VCC',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='DAP',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'HDC2080', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HDC2080'}), 'ref_prefix':'U', 'fplist':['Package_SON:Texas_PWSON-N6'], 'footprint':'Package_SON:Texas_PWSON-N6', 'keywords':'Temperature Humidity Sensor', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/hdc2080.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nHDC2080\n\nTemperature Humidity Sensor', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='4',name='DRDY',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='EP',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SHT31-DIS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SHT31-DIS'}), 'ref_prefix':'U', 'fplist':['Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm'], 'footprint':'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'keywords':'digital temperature humidity i2c', 'description':'', 'datasheet':'https://www.sensirion.com/fileadmin/user_upload/customers/sensirion/Dokumente/2_Humidity_Sensors/Datasheets/Sensirion_Humidity_Sensors_SHT3x_Datasheet_digital.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nSHT31-DIS\n\ndigital temperature humidity i2c', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ALERT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SHT4x', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SHT4x'}), 'ref_prefix':'U', 'fplist':['Sensor_Humidity:Sensirion_DFN-4_1.5x1.5mm_P0.8mm_SHT4x_NoCentralPad'], 'footprint':'Sensor_Humidity:Sensirion_DFN-4_1.5x1.5mm_P0.8mm_SHT4x_NoCentralPad', 'keywords':'Sensirion environment environmental measurement digital SHT40 SHT41 SHT45', 'description':'', 'datasheet':'https://sensirion.com/media/documents/33FD6951/624C4357/Datasheet_SHT4x.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nSHT4x\n\nSensirion environment environmental measurement digital SHT40 SHT41 SHT45', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SHTC1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SHTC1'}), 'ref_prefix':'U', 'fplist':['Sensor_Humidity:Sensirion_DFN-4-1EP_2x2mm_P1mm_EP0.7x1.6mm'], 'footprint':'Sensor_Humidity:Sensirion_DFN-4-1EP_2x2mm_P1mm_EP0.7x1.6mm', 'keywords':'Sensirion environment environmental measurement digital', 'description':'', 'datasheet':'https://www.sensirion.com/fileadmin/user_upload/customers/sensirion/Dokumente/0_Datasheets/Humidity/Sensirion_Humidity_Sensors_SHTC1_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nSHTC1\n\nSensirion environment environmental measurement digital', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si7020-A20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si7020-A20'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-6-1EP_3x3mm_P1mm_EP1.5x2.4mm'], 'footprint':'Package_DFN_QFN:DFN-6-1EP_3x3mm_P1mm_EP1.5x2.4mm', 'keywords':'I2C Humidity Temperature Sensor', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si7020-A20.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nSi7020-A20\n\nI2C Humidity Temperature Sensor', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PAD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SHT30-DIS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SHT30-DIS'}), 'ref_prefix':'U', 'fplist':['Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm'], 'footprint':'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'keywords':'digital temperature humidity i2c', 'description':'', 'datasheet':'https://www.sensirion.com/fileadmin/user_upload/customers/sensirion/Dokumente/2_Humidity_Sensors/Datasheets/Sensirion_Humidity_Sensors_SHT3x_Datasheet_digital.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nSHT30-DIS\n\ndigital temperature humidity i2c', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ALERT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SHT30A-DIS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SHT30A-DIS'}), 'ref_prefix':'U', 'fplist':['Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm'], 'footprint':'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'keywords':'digital temperature humidity automotive i2c', 'description':'', 'datasheet':'https://www.sensirion.com/fileadmin/user_upload/customers/sensirion/Dokumente/2_Humidity_Sensors/Datasheets/Sensirion_Humidity_Sensors_SHT3xA_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nSHT30A-DIS\n\ndigital temperature humidity automotive i2c', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ALERT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SHT31A-DIS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SHT31A-DIS'}), 'ref_prefix':'U', 'fplist':['Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm'], 'footprint':'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'keywords':'digital temperature humidity automotive i2c', 'description':'', 'datasheet':'https://www.sensirion.com/fileadmin/user_upload/customers/sensirion/Dokumente/2_Humidity_Sensors/Datasheets/Sensirion_Humidity_Sensors_SHT3xA_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nSHT31A-DIS\n\ndigital temperature humidity automotive i2c', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ALERT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SHT35-DIS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SHT35-DIS'}), 'ref_prefix':'U', 'fplist':['Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm'], 'footprint':'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'keywords':'digital temperature humidity i2c', 'description':'', 'datasheet':'https://www.sensirion.com/fileadmin/user_upload/customers/sensirion/Dokumente/2_Humidity_Sensors/Datasheets/Sensirion_Humidity_Sensors_SHT3x_Datasheet_digital.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nSHT35-DIS\n\ndigital temperature humidity i2c', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ALERT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SHT35A-DIS', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SHT35A-DIS'}), 'ref_prefix':'U', 'fplist':['Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm'], 'footprint':'Sensor_Humidity:Sensirion_DFN-8-1EP_2.5x2.5mm_P0.5mm_EP1.1x1.7mm', 'keywords':'digital temperature humidity automotive i2c', 'description':'', 'datasheet':'https://www.sensirion.com/fileadmin/user_upload/customers/sensirion/Dokumente/2_Humidity_Sensors/Datasheets/Sensirion_Humidity_Sensors_SHT3xA_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nSHT35A-DIS\n\ndigital temperature humidity automotive i2c', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='ADDR',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='ALERT',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{RESET}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='R',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='9',name='VSS',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'SHTC3', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'SHTC3'}), 'ref_prefix':'U', 'fplist':['Sensor_Humidity:Sensirion_DFN-4-1EP_2x2mm_P1mm_EP0.7x1.6mm', 'Sensor_Humidity:Sensirion_DFN-4-1EP_2x2mm_P1mm_EP0.7x1.6mm'], 'footprint':'Sensor_Humidity:Sensirion_DFN-4-1EP_2x2mm_P1mm_EP0.7x1.6mm', 'keywords':'Sensirion environment environmental measurement digital', 'description':'', 'datasheet':'https://www.sensirion.com/fileadmin/user_upload/customers/sensirion/Dokumente/0_Datasheets/Humidity/Sensirion_Humidity_Sensors_SHTC3_Datasheet.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nSHTC3\n\nSensirion environment environmental measurement digital', 'pins':[
            Pin(num='1',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='4',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'Si7021-A20', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'Si7021-A20'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:DFN-6-1EP_3x3mm_P1mm_EP1.5x2.4mm', 'Package_DFN_QFN:DFN-6-1EP_3x3mm_P1mm_EP1.5x2.4mm'], 'footprint':'Package_DFN_QFN:DFN-6-1EP_3x3mm_P1mm_EP1.5x2.4mm', 'keywords':'I2C Humidity Temperature Sensor', 'description':'', 'datasheet':'https://www.silabs.com/documents/public/data-sheets/Si7021-A20.pdf', 'search_text':'/usr/share/kicad/symbols/Sensor_Humidity.kicad_sym\nSi7021-A20\n\nI2C Humidity Temperature Sensor', 'pins':[
            Pin(num='1',name='SDA',func=pin_types.BIDIR,unit=1),
            Pin(num='2',name='GND',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='SCL',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='PAD',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

Amplifier_Buffer = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'BUF602xD', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BUF602xD'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-8_3.9x4.9mm_P1.27mm'], 'footprint':'Package_SO:SOIC-8_3.9x4.9mm_P1.27mm', 'keywords':'buffer amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/buf602.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Buffer.kicad_sym\nBUF602xD\n\nbuffer amplifier', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='~',func=pin_types.OUTPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'BUF602xDBV', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'BUF602xDBV'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_SMD:SOT-23-5'], 'footprint':'Package_TO_SOT_SMD:SOT-23-5', 'keywords':'buffer amplifier', 'description':'', 'datasheet':'http://www.ti.com/lit/ds/symlink/buf602.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Buffer.kicad_sym\nBUF602xDBV\n\nbuffer amplifier', 'pins':[
            Pin(num='1',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='VREF',func=pin_types.OUTPUT,unit=1),
            Pin(num='4',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='5',name='V+',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'EL2001CN', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'EL2001CN'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'Monolithic high slew rate, buffer amplifier', 'description':'', 'datasheet':'http://www.datasheetlib.com/datasheet/677973/el2001_intersil.html#datasheet', 'search_text':'/usr/share/kicad/symbols/Amplifier_Buffer.kicad_sym\nEL2001CN\n\nMonolithic high slew rate, buffer amplifier', 'pins':[
            Pin(num='1',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='7',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='NC',func=pin_types.NOCONNECT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LH0002H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LH0002H'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-5-8'], 'footprint':'Package_TO_SOT_THT:TO-5-8', 'keywords':'Buffer', 'description':'', 'datasheet':'http://www.calogic.net/pdf/LH0002_Datasheet_Rev_A.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Buffer.kicad_sym\nLH0002H\n\nBuffer', 'pins':[
            Pin(num='1',name='V1+',func=pin_types.PWRIN,unit=1),
            Pin(num='2',name='V2+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='E3',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='E4',func=pin_types.PASSIVE,unit=1),
            Pin(num='6',name='V2-',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='V1-',func=pin_types.PWRIN,unit=1),
            Pin(num='8',name='IN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM6321H', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM6321H'}), 'ref_prefix':'U', 'fplist':['Package_TO_SOT_THT:TO-5-8'], 'footprint':'Package_TO_SOT_THT:TO-5-8', 'keywords':'single buffer', 'description':'', 'datasheet':'http://www.electronica60norte.com/mwfls/pdf/LM6221.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Buffer.kicad_sym\nLM6321H\n\nsingle buffer', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='IN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM6321M', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM6321M'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'single buffer', 'description':'', 'datasheet':'http://www.electronica60norte.com/mwfls/pdf/LM6221.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Buffer.kicad_sym\nLM6321M\n\nsingle buffer', 'pins':[
            Pin(num='1',name='V-',func=pin_types.PASSIVE,unit=1),
            Pin(num='10',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='11',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='12',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='13',name='V-',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='V-',func=pin_types.PASSIVE,unit=1),
            Pin(num='2',name='V-',func=pin_types.PASSIVE,unit=1),
            Pin(num='3',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='5',name='IN',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='V-',func=pin_types.PASSIVE,unit=1),
            Pin(num='7',name='V-',func=pin_types.PASSIVE,unit=1),
            Pin(num='8',name='V-',func=pin_types.PASSIVE,unit=1),
            Pin(num='9',name='V-',func=pin_types.PASSIVE,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'LM6321N', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'LM6321N'}), 'ref_prefix':'U', 'fplist':['Package_DIP:DIP-8_W7.62mm'], 'footprint':'Package_DIP:DIP-8_W7.62mm', 'keywords':'single buffer', 'description':'', 'datasheet':'http://www.electronica60norte.com/mwfls/pdf/LM6221.pdf', 'search_text':'/usr/share/kicad/symbols/Amplifier_Buffer.kicad_sym\nLM6321N\n\nsingle buffer', 'pins':[
            Pin(num='1',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='2',name='V+',func=pin_types.PWRIN,unit=1),
            Pin(num='3',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='4',name='~',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='6',name='V-',func=pin_types.PWRIN,unit=1),
            Pin(num='7',name='NC',func=pin_types.NOCONNECT,unit=1),
            Pin(num='8',name='IN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] })])


from collections import defaultdict
from skidl import Pin, Part, Alias, SchLib, SKIDL, TEMPLATE

from skidl.pin import pin_types

SKIDL_lib_version = '0.0.1'

RF_RFID = SchLib(tool=SKIDL).add_parts(*[
        Part(**{ 'name':'HTRC11001T', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'HTRC11001T'}), 'ref_prefix':'U', 'fplist':['Package_SO:SOIC-14_3.9x8.7mm_P1.27mm'], 'footprint':'Package_SO:SOIC-14_3.9x8.7mm_P1.27mm', 'keywords':'HITAG RFID', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/037031.pdf', 'search_text':'/usr/share/kicad/symbols/RF_RFID.kicad_sym\nHTRC11001T\n\nHITAG RFID', 'pins':[
            Pin(num='1',name='VSS',func=pin_types.PWRIN,unit=1),
            Pin(num='10',name='DOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='CEXT',func=pin_types.PASSIVE,unit=1),
            Pin(num='13',name='QGND',func=pin_types.PASSIVE,unit=1),
            Pin(num='14',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='2',name='TX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='3',name='VDD',func=pin_types.PWRIN,unit=1),
            Pin(num='4',name='TX1',func=pin_types.OUTPUT,unit=1),
            Pin(num='5',name='MODE',func=pin_types.INPUT,unit=1),
            Pin(num='6',name='XTAL1',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='XTAL2',func=pin_types.OUTPUT,unit=1),
            Pin(num='8',name='SCLK',func=pin_types.INPUT,unit=1),
            Pin(num='9',name='DIN',func=pin_types.INPUT,unit=1)], 'unit_defs':[] }),
        Part(**{ 'name':'PN5120A0HN1', 'dest':TEMPLATE, 'tool':SKIDL, 'aliases':Alias({'PN5120A0HN1'}), 'ref_prefix':'U', 'fplist':['Package_DFN_QFN:HVQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm'], 'footprint':'Package_DFN_QFN:HVQFN-32-1EP_5x5mm_P0.5mm_EP3.1x3.1mm', 'keywords':'PN512 RFID', 'description':'', 'datasheet':'https://www.nxp.com/docs/en/data-sheet/PN512.pdf', 'search_text':'/usr/share/kicad/symbols/RF_RFID.kicad_sym\nPN5120A0HN1\n\nPN512 RFID', 'pins':[
            Pin(num='1',name='A1',func=pin_types.INPUT,unit=1),
            Pin(num='10',name='TVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='11',name='TX1',func=pin_types.OUTPUT,unit=1),
            Pin(num='12',name='TVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='13',name='TX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='14',name='TVSS',func=pin_types.PASSIVE,unit=1),
            Pin(num='15',name='AVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='16',name='VMID',func=pin_types.PWROUT,unit=1),
            Pin(num='17',name='RX',func=pin_types.INPUT,unit=1),
            Pin(num='18',name='AVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='19',name='AUX1',func=pin_types.OUTPUT,unit=1),
            Pin(num='2',name='PVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='20',name='AUX2',func=pin_types.OUTPUT,unit=1),
            Pin(num='21',name='OSCIN',func=pin_types.INPUT,unit=1),
            Pin(num='22',name='OSCOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='23',name='IRQ',func=pin_types.OUTPUT,unit=1),
            Pin(num='24',name='ALE',func=pin_types.INPUT,unit=1),
            Pin(num='25',name='D1',func=pin_types.BIDIR,unit=1),
            Pin(num='26',name='D2',func=pin_types.BIDIR,unit=1),
            Pin(num='27',name='D3',func=pin_types.BIDIR,unit=1),
            Pin(num='28',name='D4',func=pin_types.BIDIR,unit=1),
            Pin(num='29',name='D5',func=pin_types.BIDIR,unit=1),
            Pin(num='3',name='DVDD',func=pin_types.PWRIN,unit=1),
            Pin(num='30',name='D6',func=pin_types.BIDIR,unit=1),
            Pin(num='31',name='D7',func=pin_types.BIDIR,unit=1),
            Pin(num='32',name='A0',func=pin_types.INPUT,unit=1),
            Pin(num='33',name='EP',func=pin_types.PASSIVE,unit=1),
            Pin(num='4',name='DVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='5',name='PVSS',func=pin_types.PWRIN,unit=1),
            Pin(num='6',name='~{NRSTPD}',func=pin_types.INPUT,unit=1),
            Pin(num='7',name='SIGIN',func=pin_types.INPUT,unit=1),
            Pin(num='8',name='SIGOUT',func=pin_types.OUTPUT,unit=1),
            Pin(num='9',name='SVDD',func=pin_types.PWRIN,unit=1)], 'unit_defs':[] })])